California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 019 - CHANGES CALIFORNIA LAW TO LEGALIZE MARIJUANA AND ALLOW IT TO BE REGULATED AND TAXED. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1322303 | CREDO VICTORY FUND - YES ON 19 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1324583 | COMMUNITIES IN ACTION AGAINST THE LEGALIZATION OF MARIJUANA, A COMMITTEE AGAINST PROP. 19 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1326337 | PUBLIC SAFETY FIRST - NO ON PROP. 19, A PROJECT OF CALIFORNIA PUBLIC SAFETY FIRST | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1326759 | CITIZENS AGAINST LEGALIZING MARIJUANA, A COMMITTEE AGAINST PROPOSITION 19. | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1318272 | YES ON 19. TAX CANNABIS 2010. SPONSORED BY S.K. SEYMOUR LLC, A MEDICAL CANNABIS PROVIDER, DBA OAKSTERDAM UNIVERSITY, A CANNABIS EDUCATOR WITH SUPPORT FROM THE DRUG POLICY ACTION COMMITTEE TO TAX AND.. | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1333195 | STUDENTS FOR SENSIBLE DRUG POLICY, DAVID BRONNER, ADAM EIDINGER, AND ALAN AMSTERDAM COMMITTEE TO REGULATE CANNABIS - YES ON 19 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1325672 | DRUG POLICY ACTION COMMITTEE TO TAX AND REGULATE MARIJUANA - YES ON PROP. 19 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1331670 | CRUSADES FOR PATIENTS RIGHTS - NO ON PROP 19 SPONSORED BY CANNA CARE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1323410 | NIP IT IN THE BUD: NO ON PROP. 19 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
970230 | ASSOCIATED GENERAL CONTRACTORS ISSUES POLITICAL ACTION COMMITTEE OPPOSING PROPOSITION 19 | OPPOSE